# SubjectNameV30Rc2

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**title** | [**TitleV30Rc2**](TitleV30Rc2.md) |  | [optional] 
**subtitle** | [**SubtitleV30Rc2**](SubtitleV30Rc2.md) |  | [optional] 
**translated_title** | [**TranslatedTitleV30Rc2**](TranslatedTitleV30Rc2.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

